@@ -13,7 +13,8 @@ sub match {
     # @since v4.0.0
     my $class = shift;
     my $argv1 = shift // return undef;
-    my $index = [
+
+    state $index = [
         'connection timed out',
         'could not find a gateway for',
         'delivery time expired',
@@ -22,14 +23,15 @@ sub match {
         'has been delayed',
         'it has not been collected after',
         'message expired after sitting in queue for',
+        'message expired, connection refulsed',
         'message timed out',
         'retry time not reached for any host after a long failure period',
         'server did not respond',
         'this message has been in the queue too long',
+        'unable to deliver message after multiple retries',
         'was not reachable within the allowed queue period',
         'your message could not be delivered for more than',
     ];
-
     return 1 if grep { rindex($argv1, $_) > -1 } @$index;
     return 0;
 }
