@@ -6,19 +6,12 @@ use Encode;
 use Encode::Guess;
 use Digest::SHA;
 
-sub EOM {
-    # End of email message as a sentinel for parsing bounce messages
-    # @private
-    # @return   [String] Fixed length string like a constant
-    return '__END_OF_EMAIL_MESSAGE__';
-}
-
 sub token {
     # Create the message token from an addresser and a recipient
     # @param    [String] addr1  A sender's email address
     # @param    [String] addr2  A recipient's email address
     # @param    [Integer] epoch Machine time of the email bounce
-    # @return   [String]        Message token(MD5 hex digest) or empty string 
+    # @return   [String]        Message token(MD5 hex digest) or empty string
     #                           if the any argument is missing
     # @see       http://en.wikipedia.org/wiki/ASCII
     # @see       https://metacpan.org/pod/Digest::MD5
@@ -129,7 +122,7 @@ sub to_utf8 {
             last if $encodefrom =~ $dontencode;
             last if $encodingto =~ $dontencode;
 
-            eval { 
+            eval {
                 # Try to convert the string to UTF-8
                 Encode::from_to($tobeutf8ed, $encodefrom, 'utf8');
                 $hasencoded = 1;
@@ -220,7 +213,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018,2019 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
